searchNodes=[{"ref":"EctoMorph.html","title":"EctoMorph","module":"EctoMorph","type":"module","doc":"Utility functions for Ecto related stuff and things."},{"ref":"EctoMorph.html#generate_changeset/2","title":"EctoMorph.generate_changeset/2","module":"EctoMorph","type":"function","doc":"Casts the given data into a changeset according to the types defined by the given schema. It ignores any fields in data that are not defined in the schema, and recursively casts any embedded fields to a changeset also."},{"ref":"EctoMorph.html#into_struct/1","title":"EctoMorph.into_struct/1","module":"EctoMorph","type":"function","doc":"Take a changeset and returns a struct if there are no errors on the changeset"},{"ref":"EctoMorph.html#to_struct/2","title":"EctoMorph.to_struct/2","module":"EctoMorph","type":"function","doc":"Takes some data and tries to convert it to a struct in the shape of the given schema. Casts values to the types defined by the schema dynamically using ecto changesets. Consider this: iex&gt; Jason.encode!(%{a: :b, c: Decimal.new(&quot;10&quot;)}) |&gt; Jason.decode! %{&quot;a&quot; =&gt; &quot;b&quot;, &quot;c&quot; =&gt; &quot;10&quot;} When we decode some JSON (e.g. from a jsonb column in the db or from a network request), the JSON gets decoded by our Jason lib, but not all of the information is preserved; any atom keys become strings, and if the value is a type that is not part of the JSON spec, it is casted to a string. This means we cannot pass that JSON data directly into a struct/2 function and expect a shiny Ecto struct back (struct!/2 will just raise, and struct/2 will silently return an empty struct) UNTIL NOW! Here we take care of casting the values in the json to the type that the given schema defines, as well as turning the string keys into (existing) atoms. (We know they will be existing atoms because they will exist in the schema definitions.) We filter out any keys that are not defined in the schema. Check out the test for more full examples. Examples iex&gt; defmodule Test do ...&gt; use Ecto.Schema ...&gt; ...&gt; embedded_schema do ...&gt; field(:pageviews, :integer) ...&gt; end ...&gt; end ...&gt; {:ok, test = %Test{}} = to_struct(%{&quot;pageviews&quot; =&gt; &quot;10&quot;}, Test) ...&gt; test.pageviews 10 iex&gt; defmodule Test do ...&gt; use Ecto.Schema ...&gt; ...&gt; embedded_schema do ...&gt; field(:pageviews, :integer) ...&gt; end ...&gt; end ...&gt; json = %{&quot;pageviews&quot; =&gt; &quot;10&quot;, &quot;ignored_field&quot; =&gt; &quot;ten&quot;} ...&gt; {:ok, test = %Test{}} = to_struct(json, Test) ...&gt; test.pageviews 10"}]